You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by el...@apache.org on 2012/02/15 17:29:06 UTC

svn commit: r1244570 - in /directory: apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/api/schema/ apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/api/schema/registries/synchronizers/ apacheds/trunk/core-sha...

Author: elecharny
Date: Wed Feb 15 16:29:04 2012
New Revision: 1244570

URL: http://svn.apache.org/viewvc?rev=1244570&view=rev
Log:
o Renamed DITContentRule to DContentRule (fist step toward the rename of this class to DitContentRule, as all the other camel cased classes)

Added:
    directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/DContentRule.java
      - copied, changed from r1244564, directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/DITContentRule.java
Removed:
    directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/DITContentRule.java
Modified:
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/api/schema/DescriptionParsers.java
    directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/api/schema/registries/synchronizers/DitContentRuleSynchronizer.java
    directory/apacheds/trunk/core-shared/src/main/java/org/apache/directory/server/core/shared/SchemaService.java
    directory/apacheds/trunk/interceptors/schema/src/main/java/org/apache/directory/server/core/schema/SchemaSubentryManager.java
    directory/apacheds/trunk/interceptors/schema/src/main/java/org/apache/directory/server/core/schema/SchemaSubentryModifier.java
    directory/shared/trunk/ldap/client/api/src/main/java/org/apache/directory/ldap/client/api/DefaultSchemaLoader.java
    directory/shared/trunk/ldap/model/src/main/antlr/schema.g
    directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/AttributesFactory.java
    directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/DescriptionUtils.java
    directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/SchemaManager.java
    directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/SchemaUtils.java
    directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/parsers/DITContentRuleDescriptionSchemaParser.java
    directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/registries/AbstractSchemaLoader.java
    directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/registries/DITContentRuleRegistry.java
    directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/registries/DefaultDITContentRuleRegistry.java
    directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/registries/ImmutableDITContentRuleRegistry.java
    directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/registries/Registries.java
    directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/registries/helper/DitContentRuleHelper.java
    directory/shared/trunk/ldap/model/src/test/java/org/apache/directory/shared/ldap/model/schema/syntaxes/parser/DITContentRuleDescriptionSchemaParserTest.java
    directory/shared/trunk/ldap/schema/data/src/test/java/org/apache/directory/shared/ldap/schemaloader/SchemaManagerAddTest.java
    directory/shared/trunk/ldap/schema/data/src/test/java/org/apache/directory/shared/ldap/schemaloader/SchemaManagerDelTest.java

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/api/schema/DescriptionParsers.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/api/schema/DescriptionParsers.java?rev=1244570&r1=1244569&r2=1244570&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/api/schema/registries/synchronizers/DitContentRuleSynchronizer.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/api/schema/registries/synchronizers/DitContentRuleSynchronizer.java Wed Feb 15 16:29:04 2012
@@ -25,7 +25,7 @@ import org.apache.directory.shared.ldap.
 import org.apache.directory.shared.ldap.model.exception.LdapException;
 import org.apache.directory.shared.ldap.model.name.Dn;
 import org.apache.directory.shared.ldap.model.name.Rdn;
-import org.apache.directory.shared.ldap.model.schema.DITContentRule;
+import org.apache.directory.shared.ldap.model.schema.DContentRule;
 import org.apache.directory.shared.ldap.model.schema.SchemaManager;
 
 
@@ -109,13 +109,13 @@ public class DitContentRuleSynchronizer 
     }
 
 
-    public void add( DITContentRule dcr )
+    public void add( DContentRule dcr )
     {
         // TODO Auto-generated method stub
     }
 
 
-    public void delete( DITContentRule dcr, boolean cascade )
+    public void delete( DContentRule dcr, boolean cascade )
     {
         // TODO Auto-generated method stub
     }

Modified: directory/apacheds/trunk/core-shared/src/main/java/org/apache/directory/server/core/shared/SchemaService.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-shared/src/main/java/org/apache/directory/server/core/shared/SchemaService.java?rev=1244570&r1=1244569&r2=1244570&view=diff
==============================================================================
--- directory/apacheds/trunk/core-shared/src/main/java/org/apache/directory/server/core/shared/SchemaService.java (original)
+++ directory/apacheds/trunk/core-shared/src/main/java/org/apache/directory/server/core/shared/SchemaService.java Wed Feb 15 16:29:04 2012
@@ -34,7 +34,7 @@ import org.apache.directory.shared.ldap.
 import org.apache.directory.shared.ldap.model.exception.LdapException;
 import org.apache.directory.shared.ldap.model.name.Dn;
 import org.apache.directory.shared.ldap.model.schema.AttributeType;
-import org.apache.directory.shared.ldap.model.schema.DITContentRule;
+import org.apache.directory.shared.ldap.model.schema.DContentRule;
 import org.apache.directory.shared.ldap.model.schema.DITStructureRule;
 import org.apache.directory.shared.ldap.model.schema.LdapComparator;
 import org.apache.directory.shared.ldap.model.schema.LdapSyntax;
@@ -186,7 +186,7 @@ public class SchemaService
         Attribute attr = new DefaultAttribute(
             schemaManager.getAttributeType( SchemaConstants.DIT_CONTENT_RULES_AT ) );
 
-        for ( DITContentRule ditContentRule : schemaManager.getDITContentRuleRegistry() )
+        for ( DContentRule ditContentRule : schemaManager.getDITContentRuleRegistry() )
         {
             attr.add( SchemaUtils.render( ditContentRule ).toString() );
         }

Modified: directory/apacheds/trunk/interceptors/schema/src/main/java/org/apache/directory/server/core/schema/SchemaSubentryManager.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/interceptors/schema/src/main/java/org/apache/directory/server/core/schema/SchemaSubentryManager.java?rev=1244570&r1=1244569&r2=1244570&view=diff
==============================================================================
--- directory/apacheds/trunk/interceptors/schema/src/main/java/org/apache/directory/server/core/schema/SchemaSubentryManager.java (original)
+++ directory/apacheds/trunk/interceptors/schema/src/main/java/org/apache/directory/server/core/schema/SchemaSubentryManager.java Wed Feb 15 16:29:04 2012
@@ -41,7 +41,7 @@ import org.apache.directory.shared.ldap.
 import org.apache.directory.shared.ldap.model.exception.LdapUnwillingToPerformException;
 import org.apache.directory.shared.ldap.model.message.ResultCodeEnum;
 import org.apache.directory.shared.ldap.model.schema.AttributeType;
-import org.apache.directory.shared.ldap.model.schema.DITContentRule;
+import org.apache.directory.shared.ldap.model.schema.DContentRule;
 import org.apache.directory.shared.ldap.model.schema.DITStructureRule;
 import org.apache.directory.shared.ldap.model.schema.LdapSyntax;
 import org.apache.directory.shared.ldap.model.schema.MatchingRule;
@@ -399,9 +399,9 @@ public class SchemaSubentryManager
                 break;
 
             case ( DIT_CONTENT_RULE_INDEX ):
-                DITContentRule[] dcrs = parsers.parseDitContentRules( mods );
+                DContentRule[] dcrs = parsers.parseDitContentRules( mods );
 
-                for ( DITContentRule dcr : dcrs )
+                for ( DContentRule dcr : dcrs )
                 {
                     subentryModifier.deleteSchemaObject( nextInterceptor, position, modifyContext, dcr );
                 }
@@ -538,9 +538,9 @@ public class SchemaSubentryManager
                 break;
 
             case ( DIT_CONTENT_RULE_INDEX ):
-                DITContentRule[] dcrs = parsers.parseDitContentRules( mods );
+                DContentRule[] dcrs = parsers.parseDitContentRules( mods );
 
-                for ( DITContentRule dcr : dcrs )
+                for ( DContentRule dcr : dcrs )
                 {
                     subentryModifier.addSchemaObject( nextInterceptor, position, modifyContext, dcr );
                 }

Modified: directory/apacheds/trunk/interceptors/schema/src/main/java/org/apache/directory/server/core/schema/SchemaSubentryModifier.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/interceptors/schema/src/main/java/org/apache/directory/server/core/schema/SchemaSubentryModifier.java?rev=1244570&r1=1244569&r2=1244570&view=diff
==============================================================================
--- directory/apacheds/trunk/interceptors/schema/src/main/java/org/apache/directory/server/core/schema/SchemaSubentryModifier.java (original)
+++ directory/apacheds/trunk/interceptors/schema/src/main/java/org/apache/directory/server/core/schema/SchemaSubentryModifier.java Wed Feb 15 16:29:04 2012
@@ -34,7 +34,7 @@ import org.apache.directory.shared.ldap.
 import org.apache.directory.shared.ldap.model.name.Dn;
 import org.apache.directory.shared.ldap.model.schema.AttributeType;
 import org.apache.directory.shared.ldap.model.schema.AttributesFactory;
-import org.apache.directory.shared.ldap.model.schema.DITContentRule;
+import org.apache.directory.shared.ldap.model.schema.DContentRule;
 import org.apache.directory.shared.ldap.model.schema.DITStructureRule;
 import org.apache.directory.shared.ldap.model.schema.LdapSyntax;
 import org.apache.directory.shared.ldap.model.schema.MatchingRule;
@@ -110,7 +110,7 @@ public class SchemaSubentryModifier
         {
             buf.append( SchemaConstants.DIT_STRUCTURE_RULES_AT );
         }
-        else if ( obj instanceof DITContentRule )
+        else if ( obj instanceof DContentRule )
         {
             buf.append( SchemaConstants.DIT_CONTENT_RULES_AT );
         }

Modified: directory/shared/trunk/ldap/client/api/src/main/java/org/apache/directory/ldap/client/api/DefaultSchemaLoader.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/client/api/src/main/java/org/apache/directory/ldap/client/api/DefaultSchemaLoader.java?rev=1244570&r1=1244569&r2=1244570&view=diff
==============================================================================
--- directory/shared/trunk/ldap/client/api/src/main/java/org/apache/directory/ldap/client/api/DefaultSchemaLoader.java (original)
+++ directory/shared/trunk/ldap/client/api/src/main/java/org/apache/directory/ldap/client/api/DefaultSchemaLoader.java Wed Feb 15 16:29:04 2012
@@ -38,7 +38,7 @@ import org.apache.directory.shared.ldap.
 import org.apache.directory.shared.ldap.model.name.Dn;
 import org.apache.directory.shared.ldap.model.schema.AttributeType;
 import org.apache.directory.shared.ldap.model.schema.AttributesFactory;
-import org.apache.directory.shared.ldap.model.schema.DITContentRule;
+import org.apache.directory.shared.ldap.model.schema.DContentRule;
 import org.apache.directory.shared.ldap.model.schema.DITStructureRule;
 import org.apache.directory.shared.ldap.model.schema.LdapSyntax;
 import org.apache.directory.shared.ldap.model.schema.MatchingRule;
@@ -298,7 +298,7 @@ public class DefaultSchemaLoader extends
 
             try
             {
-                DITContentRule ditContentRule = DCR_DESCR_SCHEMA_PARSER.parseDITContentRuleDescription( desc );
+                DContentRule ditContentRule = DCR_DESCR_SCHEMA_PARSER.parseDITContentRuleDescription( desc );
 
                 updateSchemas( ditContentRule );
             }
@@ -654,9 +654,9 @@ public class DefaultSchemaLoader extends
             {
                 SchemaObject schemaObject = schemaObjectWrapper.get();
 
-                if ( schemaObject instanceof DITContentRule )
+                if ( schemaObject instanceof DContentRule )
                 {
-                    DITContentRule ditContentRule = ( DITContentRule ) schemaObject;
+                    DContentRule ditContentRule = ( DContentRule ) schemaObject;
 
                     Entry ditContentRuleEntry = factory.convert( ditContentRule, schema, null );
 

Modified: directory/shared/trunk/ldap/model/src/main/antlr/schema.g
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/model/src/main/antlr/schema.g?rev=1244570&r1=1244569&r2=1244570&view=diff
==============================================================================
--- directory/shared/trunk/ldap/model/src/main/antlr/schema.g (original)
+++ directory/shared/trunk/ldap/model/src/main/antlr/schema.g Wed Feb 15 16:29:04 2012
@@ -27,7 +27,7 @@ import java.util.List;
 import java.util.Map;
 
 import org.apache.directory.shared.ldap.model.schema.parsers.LdapComparatorDescription;
-import org.apache.directory.shared.ldap.model.schema.DITContentRule;
+import org.apache.directory.shared.ldap.model.schema.DContentRule;
 import org.apache.directory.shared.ldap.model.schema.DITStructureRule;
 import org.apache.directory.shared.ldap.model.schema.LdapSyntax;
 import org.apache.directory.shared.ldap.model.schema.MatchingRule;
@@ -612,13 +612,13 @@ matchingRuleUseDescription returns [Matc
      *    extensions WSP RPAREN      ; extensions
      * </pre>
     */
-ditContentRuleDescription returns [DITContentRule ditContentRule]
+ditContentRuleDescription returns [DContentRule ditContentRule]
     {
         matchedProduction( "ditContentRuleDescription()" );
         ElementTracker et = new ElementTracker();
     }
     :
-    ( oid:STARTNUMERICOID { ditContentRule = new DITContentRule(numericoid(oid.getText())); } )
+    ( oid:STARTNUMERICOID { ditContentRule = new DContentRule(numericoid(oid.getText())); } )
     (
         ( name:NAME { et.track("NAME", name); ditContentRule.setNames(qdescrs(name.getText())); } )
         |

Modified: directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/AttributesFactory.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/AttributesFactory.java?rev=1244570&r1=1244569&r2=1244570&view=diff
==============================================================================
--- directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/AttributesFactory.java (original)
+++ directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/AttributesFactory.java Wed Feb 15 16:29:04 2012
@@ -31,7 +31,7 @@ import org.apache.directory.shared.ldap.
 import org.apache.directory.shared.ldap.model.entry.Entry;
 import org.apache.directory.shared.ldap.model.exception.LdapException;
 import org.apache.directory.shared.ldap.model.schema.AttributeType;
-import org.apache.directory.shared.ldap.model.schema.DITContentRule;
+import org.apache.directory.shared.ldap.model.schema.DContentRule;
 import org.apache.directory.shared.ldap.model.schema.DITStructureRule;
 import org.apache.directory.shared.ldap.model.schema.LdapComparator;
 import org.apache.directory.shared.ldap.model.schema.LdapSyntax;
@@ -81,9 +81,9 @@ public class AttributesFactory
         {
             return convert( ( DITStructureRule ) obj, schema, schemaManager );
         }
-        else if ( obj instanceof DITContentRule )
+        else if ( obj instanceof DContentRule )
         {
-            return convert( ( DITContentRule ) obj, schema, schemaManager );
+            return convert( ( DContentRule ) obj, schema, schemaManager );
         }
         else if ( obj instanceof NameForm )
         {
@@ -231,7 +231,7 @@ public class AttributesFactory
     }
 
 
-    public Entry convert( DITContentRule dITContentRule, Schema schema, SchemaManager schemaManager )
+    public Entry convert( DContentRule dITContentRule, Schema schema, SchemaManager schemaManager )
     {
         Entry entry = new DefaultEntry( schemaManager );
 

Copied: directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/DContentRule.java (from r1244564, directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/DITContentRule.java)
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/DContentRule.java?p2=directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/DContentRule.java&p1=directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/DITContentRule.java&r1=1244564&r2=1244570&rev=1244570&view=diff
==============================================================================
--- directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/SchemaManager.java (original)
+++ directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/SchemaManager.java Wed Feb 15 16:29:04 2012
@@ -530,9 +530,9 @@ public interface SchemaManager
 
 
     /**
-     * Get an immutable reference on the DITContentRule registry
+     * Get an immutable reference on the DContentRule registry
      * 
-     * @return A reference to the DITContentRule registry.
+     * @return A reference to the DContentRule registry.
      */
     DITContentRuleRegistry getDITContentRuleRegistry();
 

Modified: directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/SchemaUtils.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/SchemaUtils.java?rev=1244570&r1=1244569&r2=1244570&view=diff
==============================================================================
--- directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/SchemaUtils.java (original)
+++ directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/SchemaUtils.java Wed Feb 15 16:29:04 2012
@@ -902,7 +902,7 @@ public final class SchemaUtils
     /**
      * NOT FULLY IMPLEMENTED!
      */
-    public static StringBuffer render( DITContentRule dcr )
+    public static StringBuffer render( DContentRule dcr )
     {
         StringBuffer buf = new StringBuffer();
         buf.append( "( " ).append( dcr.getOid() );

Modified: directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/parsers/DITContentRuleDescriptionSchemaParser.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/parsers/DITContentRuleDescriptionSchemaParser.java?rev=1244570&r1=1244569&r2=1244570&view=diff
==============================================================================
--- directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/registries/AbstractSchemaLoader.java (original)
+++ directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/registries/AbstractSchemaLoader.java Wed Feb 15 16:29:04 2012
@@ -569,7 +569,7 @@ public abstract class AbstractSchemaLoad
      * @return the created DitContentRule instance
      * @throws Exception If the registering failed
      *
-    protected DITContentRule registerDitContentRule( Registries registries, LdifEntry entry, Schema schema)
+    protected DContentRule registerDitContentRule( Registries registries, LdifEntry entry, Schema schema)
         throws Exception
     {
         throw new NotImplementedException( "Need to implement factory " +

Modified: directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/registries/DITContentRuleRegistry.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/registries/DITContentRuleRegistry.java?rev=1244570&r1=1244569&r2=1244570&view=diff
==============================================================================
--- directory/shared/trunk/ldap/model/src/test/java/org/apache/directory/shared/ldap/model/schema/syntaxes/parser/DITContentRuleDescriptionSchemaParserTest.java (original)
+++ directory/shared/trunk/ldap/model/src/test/java/org/apache/directory/shared/ldap/model/schema/syntaxes/parser/DITContentRuleDescriptionSchemaParserTest.java Wed Feb 15 16:29:04 2012
@@ -29,7 +29,7 @@ import java.text.ParseException;
 
 import com.mycila.junit.concurrent.Concurrency;
 import com.mycila.junit.concurrent.ConcurrentJunitRunner;
-import org.apache.directory.shared.ldap.model.schema.DITContentRule;
+import org.apache.directory.shared.ldap.model.schema.DContentRule;
 import org.apache.directory.shared.ldap.model.schema.parsers.DITContentRuleDescriptionSchemaParser;
 import org.junit.After;
 import org.junit.Before;
@@ -121,7 +121,7 @@ public class DITContentRuleDescriptionSc
     public void testAux() throws ParseException
     {
         String value = null;
-        DITContentRule ditContentRule = null;
+        DContentRule ditContentRule = null;
 
         // no AUX
         value = "( 1.1 )";
@@ -260,7 +260,7 @@ public class DITContentRuleDescriptionSc
     public void testMust() throws ParseException
     {
         String value = null;
-        DITContentRule ditContentRule = null;
+        DContentRule ditContentRule = null;
 
         // no MUST
         value = "( 1.1 )";
@@ -321,7 +321,7 @@ public class DITContentRuleDescriptionSc
     public void testMay() throws ParseException
     {
         String value = null;
-        DITContentRule ditContentRule = null;
+        DContentRule ditContentRule = null;
 
         // no MAY
         value = "( 1.1 )";
@@ -370,7 +370,7 @@ public class DITContentRuleDescriptionSc
     public void testNot() throws ParseException
     {
         String value = null;
-        DITContentRule ditContentRule = null;
+        DContentRule ditContentRule = null;
 
         // no NOT
         value = "( 1.1 )";
@@ -431,7 +431,7 @@ public class DITContentRuleDescriptionSc
     public void testFull() throws ParseException
     {
         String value = null;
-        DITContentRule ditContentRule = null;
+        DContentRule ditContentRule = null;
 
         value = "( 1.2.3.4.5.6.7.8.9.0 NAME ( 'abcdefghijklmnopqrstuvwxyz-ABCDEFGHIJKLMNOPQRSTUVWXYZ-0123456789' 'test' ) DESC 'Descripton \u00E4\u00F6\u00FC\u00DF \u90E8\u9577' OBSOLETE AUX ( 2.3.4.5.6.7.8.9.0.1 $ abcdefghijklmnopqrstuvwxyz-ABCDEFGHIJKLMNOPQRSTUVWXYZ-0123456789 ) MUST ( 3.4.5.6.7.8.9.0.1.2 $ abcdefghijklmnopqrstuvwxyz-ABCDEFGHIJKLMNOPQRSTUVWXYZ-0123456789 ) MAY ( 4.5.6.7.8.9.0.1.2.3 $ abcdefghijklmnopqrstuvwxyz-ABCDEFGHIJKLMNOPQRSTUVWXYZ-0123456789 ) NOT ( 5.6.7.8.9.0.1.2.3.4 $ abcdefghijklmnopqrstuvwxyz-ABCDEFGHIJKLMNOPQRSTUVWXYZ-0123456789 ) X-TEST-a ('test1-1' 'test1-2') X-TEST-b ('test2-1' 'test2-2') )";
         ditContentRule = parser.parseDITContentRuleDescription( value );

Modified: directory/shared/trunk/ldap/schema/data/src/test/java/org/apache/directory/shared/ldap/schemaloader/SchemaManagerAddTest.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/schema/data/src/test/java/org/apache/directory/shared/ldap/schemaloader/SchemaManagerAddTest.java?rev=1244570&r1=1244569&r2=1244570&view=diff
==============================================================================
--- directory/shared/trunk/ldap/schema/data/src/test/java/org/apache/directory/shared/ldap/schemaloader/SchemaManagerAddTest.java (original)
+++ directory/shared/trunk/ldap/schema/data/src/test/java/org/apache/directory/shared/ldap/schemaloader/SchemaManagerAddTest.java Wed Feb 15 16:29:04 2012
@@ -923,7 +923,7 @@ public class SchemaManagerAddTest
 
 
     //=========================================================================
-    // DITContentRule addition tests
+    // DContentRule addition tests
     //-------------------------------------------------------------------------
     // TODO
 

Modified: directory/shared/trunk/ldap/schema/data/src/test/java/org/apache/directory/shared/ldap/schemaloader/SchemaManagerDelTest.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/schema/data/src/test/java/org/apache/directory/shared/ldap/schemaloader/SchemaManagerDelTest.java?rev=1244570&r1=1244569&r2=1244570&view=diff
==============================================================================
--- directory/shared/trunk/ldap/schema/data/src/test/java/org/apache/directory/shared/ldap/schemaloader/SchemaManagerDelTest.java (original)
+++ directory/shared/trunk/ldap/schema/data/src/test/java/org/apache/directory/shared/ldap/schemaloader/SchemaManagerDelTest.java Wed Feb 15 16:29:04 2012
@@ -459,7 +459,7 @@ public class SchemaManagerDelTest
 
 
     //=========================================================================
-    // DITContentRule deletion tests
+    // DContentRule deletion tests
     //-------------------------------------------------------------------------
     // TODO
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/api/schema/DescriptionParsers.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/api/schema/DescriptionParsers.java Wed Feb 15 16:29:04 2012
@@ -30,7 +30,7 @@ import org.apache.directory.shared.ldap.
 import org.apache.directory.shared.ldap.model.exception.LdapUnwillingToPerformException;
 import org.apache.directory.shared.ldap.model.message.ResultCodeEnum;
 import org.apache.directory.shared.ldap.model.schema.AttributeType;
-import org.apache.directory.shared.ldap.model.schema.DITContentRule;
+import org.apache.directory.shared.ldap.model.schema.DContentRule;
 import org.apache.directory.shared.ldap.model.schema.DITStructureRule;
 import org.apache.directory.shared.ldap.model.schema.LdapSyntax;
 import org.apache.directory.shared.ldap.model.schema.MatchingRule;
@@ -75,7 +75,7 @@ public class DescriptionParsers
     private static final ObjectClass[] EMPTY_OBJECT_CLASSES = new ObjectClass[0];
     private static final MatchingRuleUse[] EMPTY_MATCHING_RULE_USES = new MatchingRuleUse[0];
     private static final DITStructureRule[] EMPTY_DIT_STRUCTURE_RULES = new DITStructureRule[0];
-    private static final DITContentRule[] EMPTY_DIT_CONTENT_RULES = new DITContentRule[0];
+    private static final DContentRule[] EMPTY_DIT_CONTENT_RULES = new DContentRule[0];
     private static final NameForm[] EMPTY_NAME_FORMS = new NameForm[0];
 
     /** The SchemaObject description's parsers */
@@ -576,23 +576,23 @@ public class DescriptionParsers
      * schema entities.
      * 
      * @param attr the attribute containing dITContentRuleDescriptions
      * @return the set of DITContentRule objects for the descriptions
      * @throws LdapException if there are problems parsing the descriptions
      */
-    public DITContentRule[] parseDitContentRules( Attribute attr ) throws LdapException
+    public DContentRule[] parseDitContentRules( Attribute attr ) throws LdapException
     {
         if ( attr == null || attr.size() == 0 )
         {
             return EMPTY_DIT_CONTENT_RULES;
         }
 
-        DITContentRule[] ditContentRules = new DITContentRule[attr.size()];
+        DContentRule[] ditContentRules = new DContentRule[attr.size()];
 
         int pos = 0;
 
         for ( Value<?> value : attr )
         {
-            DITContentRule ditContentRule = null;
+            DContentRule ditContentRule = null;
 
             try
             {
@@ -576,23 +576,23 @@ public class DescriptionParsers
      * 
      * @param attr the attribute containing dITContentRuleDescriptions
-     * @return the set of DITContentRule objects for the descriptions
+     * @return the set of DContentRule objects for the descriptions
      * @throws LdapException if there are problems parsing the descriptions
      */

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/api/schema/registries/synchronizers/DitContentRuleSynchronizer.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/api/schema/registries/synchronizers/DitContentRuleSynchronizer.java?rev=1244570&r1=1244569&r2=1244570&view=diff
==============================================================================
--- directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/DITContentRule.java (original)
+++ directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/DContentRule.java Wed Feb 15 16:29:04 2012
@@ -108,12 +108,12 @@ import org.apache.directory.shared.i18n.
  * @see <a
  *      href="http://www.ietf.org/internet-drafts/draft-ietf-ldapbis-models-11.txt">ldapbis
  *      [MODELS]</a>
- * @see DescriptionUtils#getDescription(DITContentRule)
+ * @see DescriptionUtils#getDescription(DContentRule)
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  */
 // super.hashCode is final
 @SuppressWarnings("PMD.OverrideBothEqualsAndHashcode")
-public class DITContentRule extends AbstractSchemaObject
+public class DContentRule extends AbstractSchemaObject
 {
     /** The list of Auxiliary ObjectClass OIDs entries may belong to */
     private List<String> auxObjectClassOids;
@@ -141,11 +141,11 @@ public class DITContentRule extends Abst
 
 
     /**
      * Creates a DITContentRule object using a unique OID.
      * 
      * @param oid the OID for this DITContentRule
      */
-    public DITContentRule( String oid )
+    public DContentRule( String oid )
     {
         super( SchemaObjectType.DIT_CONTENT_RULE, oid );
 
@@ -573,11 +573,11 @@ public class DITContentRule extends Abst
 
 
     /**
-     * Copy a DITContentRule
+     * Copy a DContentRule
      */
-    public DITContentRule copy()
+    public DContentRule copy()
     {
-        DITContentRule copy = new DITContentRule( oid );
+        DContentRule copy = new DContentRule( oid );
 
         // Copy the SchemaObject common data
         copy.copy( this );
@@ -643,13 +643,13 @@ public class DITContentRule extends Abst
             return false;
         }
 
-        if ( !( o instanceof DITContentRule ) )
+        if ( !( o instanceof DContentRule ) )
         {
             return false;
         }
 
         @SuppressWarnings("unused")
-        DITContentRule that = ( DITContentRule ) o;
+        DContentRule that = ( DContentRule ) o;
 
         // TODO : complete the check
         return true;
@@ -141,11 +141,11 @@ public class DITContentRule extends Abst
 
     /**
-     * Creates a DITContentRule object using a unique OID.
+     * Creates a DContentRule object using a unique OID.
      * 
@@ -141,11 +141,11 @@ public class DITContentRule extends Abst
      * 
-     * @param oid the OID for this DITContentRule
+     * @param oid the OID for this DContentRule
      */

Modified: directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/DescriptionUtils.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/DescriptionUtils.java?rev=1244570&r1=1244569&r2=1244570&view=diff
==============================================================================
--- directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/DescriptionUtils.java (original)
+++ directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/DescriptionUtils.java Wed Feb 15 16:29:04 2012
@@ -31,8 +31,8 @@ import java.util.Map;
  * the following objects:
  * <ul>
  * <li><a href="./AttributeType.html">AttributeType</a></li>
- * <li><a href="./DITContentRule.html">DITContentRule</a></li>
- * <li><a href="./DITContentRule.html">DITStructureRule</a></li>
+ * <li><a href="./DContentRule.html">DContentRule</a></li>
+ * <li><a href="./DContentRule.html">DITStructureRule</a></li>
  * <li><a href="./LdapComparator.html">Syntax</a></li>
  * <li><a href="./MatchingRule.html">MatchingRule</a></li>
  * <li><a href="./MatchingRuleUse.html">MatchingRuleUse</a></li>
@@ -206,7 +206,7 @@ public final class DescriptionUtils
 
 
     /**
      * Generates the DITContentRuleDescription for a DITContentRule as defined
      * by the syntax: 1.3.6.1.4.1.1466.115.121.1.16. Only the right hand side of
      * the description starting at the opening parenthesis is generated: that
      * is 'DITContentRuleDescription = ' is not generated.
@@ -229,7 +229,7 @@ public final class DescriptionUtils
      * @return the specification according to the DITContentRuleDescription
      *         syntax
      */
-    public static String getDescription( DITContentRule dITContentRule )
+    public static String getDescription( DContentRule dITContentRule )
     {
         StringBuilder buf = new StringBuilder( "( " );
         buf.append( dITContentRule.getOid() );
@@ -206,7 +206,7 @@ public final class DescriptionUtils
 
     /**
-     * Generates the DITContentRuleDescription for a DITContentRule as defined
+     * Generates the DITContentRuleDescription for a DContentRule as defined
      * by the syntax: 1.3.6.1.4.1.1466.115.121.1.16. Only the right hand side of
      * the description starting at the opening parenthesis is generated: that

Modified: directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/SchemaManager.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/SchemaManager.java?rev=1244570&r1=1244569&r2=1244570&view=diff
==============================================================================
--- directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/parsers/DITContentRuleDescriptionSchemaParser.java (original)
+++ directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/parsers/DITContentRuleDescriptionSchemaParser.java Wed Feb 15 16:29:04 2012
@@ -23,7 +23,7 @@ package org.apache.directory.shared.ldap
 import java.text.ParseException;
 
 import org.apache.directory.shared.i18n.I18n;
-import org.apache.directory.shared.ldap.model.schema.DITContentRule;
+import org.apache.directory.shared.ldap.model.schema.DContentRule;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -70,10 +70,10 @@ public class DITContentRuleDescriptionSc
      * @return the parsed DITContentRuleDescription bean
      * @throws ParseException if there are any recognition errors (bad syntax)
      */
-    public synchronized DITContentRule parseDITContentRuleDescription( String ditContentRuleDescription )
+    public synchronized DContentRule parseDITContentRuleDescription( String ditContentRuleDescription )
         throws ParseException
     {
-        LOG.debug( "Parsing a DITContentRule : {}", ditContentRuleDescription );
+        LOG.debug( "Parsing a DContentRule : {}", ditContentRuleDescription );
 
         if ( ditContentRuleDescription == null )
         {
@@ -85,7 +85,7 @@ public class DITContentRuleDescriptionSc
 
         try
         {
-            DITContentRule ditContentRule = parser.ditContentRuleDescription();
+            DContentRule ditContentRule = parser.ditContentRuleDescription();
 
             // Update the schemaName
             updateSchemaName( ditContentRule );
@@ -109,13 +109,13 @@ public class DITContentRuleDescriptionSc
 
 
     /**
      * Parses a DITContentRule description.
      * 
      * @param schemaDescription The DITContentRule description to parse
      * @return An instance of DITContentRule
      * @throws ParseException {@inheritDoc}
      */
-    public DITContentRule parse( String schemaDescription ) throws ParseException
+    public DContentRule parse( String schemaDescription ) throws ParseException
     {
         return parseDITContentRuleDescription( schemaDescription );
     }
@@ -109,13 +109,13 @@ public class DITContentRuleDescriptionSc
 
     /**
-     * Parses a DITContentRule description.
+     * Parses a DContentRule description.
      * 
@@ -109,13 +109,13 @@ public class DITContentRuleDescriptionSc
      * 
-     * @param schemaDescription The DITContentRule description to parse
-     * @return An instance of DITContentRule
+     * @param schemaDescription The DContentRule description to parse
+     * @return An instance of DContentRule
      * @throws ParseException {@inheritDoc}
      */

Modified: directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/registries/AbstractSchemaLoader.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/registries/AbstractSchemaLoader.java?rev=1244570&r1=1244569&r2=1244570&view=diff
==============================================================================
--- directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/registries/DITContentRuleRegistry.java (original)
+++ directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/registries/DITContentRuleRegistry.java Wed Feb 15 16:29:04 2012
@@ -20,16 +20,16 @@
 package org.apache.directory.shared.ldap.model.schema.registries;
 
 
-import org.apache.directory.shared.ldap.model.schema.DITContentRule;
+import org.apache.directory.shared.ldap.model.schema.DContentRule;
 
 
 /**
  * An DITContentRule registry's service interface.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  */
-public interface DITContentRuleRegistry extends SchemaObjectRegistry<DITContentRule>,
-    Iterable<DITContentRule>
+public interface DITContentRuleRegistry extends SchemaObjectRegistry<DContentRule>,
+    Iterable<DContentRule>
 {
     /**
      * Copy the DITContentRuleRegistry
@@ -20,16 +20,16 @@
 
 /**
- * An DITContentRule registry's service interface.
+ * An DContentRule registry's service interface.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>

Modified: directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/registries/DefaultDITContentRuleRegistry.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/registries/DefaultDITContentRuleRegistry.java?rev=1244570&r1=1244569&r2=1244570&view=diff
==============================================================================
--- directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/registries/DefaultDITContentRuleRegistry.java (original)
+++ directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/registries/DefaultDITContentRuleRegistry.java Wed Feb 15 16:29:04 2012
@@ -20,16 +20,16 @@
 package org.apache.directory.shared.ldap.model.schema.registries;
 
 
-import org.apache.directory.shared.ldap.model.schema.DITContentRule;
+import org.apache.directory.shared.ldap.model.schema.DContentRule;
 import org.apache.directory.shared.ldap.model.schema.SchemaObjectType;
 
 
 /**
  * An DITContentRule registry's service default implementation.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  */
-public class DefaultDITContentRuleRegistry extends DefaultSchemaObjectRegistry<DITContentRule>
+public class DefaultDITContentRuleRegistry extends DefaultSchemaObjectRegistry<DContentRule>
     implements DITContentRuleRegistry
 {
     /**
@@ -37,7 +37,7 @@ public class DefaultDITContentRuleRegist
      */
     public DefaultDITContentRuleRegistry()
     {
-        super( SchemaObjectType.DIT_CONTENT_RULE, new OidRegistry<DITContentRule>() );
+        super( SchemaObjectType.DIT_CONTENT_RULE, new OidRegistry<DContentRule>() );
     }
 
 
@@ -20,16 +20,16 @@
 
 /**
- * An DITContentRule registry's service default implementation.
+ * An DContentRule registry's service default implementation.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>

Modified: directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/registries/ImmutableDITContentRuleRegistry.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/registries/ImmutableDITContentRuleRegistry.java?rev=1244570&r1=1244569&r2=1244570&view=diff
==============================================================================
--- directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/registries/ImmutableDITContentRuleRegistry.java (original)
+++ directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/registries/ImmutableDITContentRuleRegistry.java Wed Feb 15 16:29:04 2012
@@ -26,25 +26,25 @@ import org.apache.directory.shared.i18n.
 import org.apache.directory.shared.ldap.model.exception.LdapException;
 import org.apache.directory.shared.ldap.model.exception.LdapUnwillingToPerformException;
 import org.apache.directory.shared.ldap.model.message.ResultCodeEnum;
-import org.apache.directory.shared.ldap.model.schema.DITContentRule;
+import org.apache.directory.shared.ldap.model.schema.DContentRule;
 import org.apache.directory.shared.ldap.model.schema.SchemaObjectType;
 
 
 /**
  * An immutable wrapper of the DITContentRule registry.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  */
 public class ImmutableDITContentRuleRegistry implements DITContentRuleRegistry
 {
     /** The wrapped DITContentRule registry */
     DITContentRuleRegistry immutableDITContentRuleRegistry;
 
 
     /**
      * Creates a new instance of ImmutableDITContentRuleRegistry.
      *
      * @param ditContentRuleRegistry The wrapped DITContentRule registry
      */
     public ImmutableDITContentRuleRegistry( DITContentRuleRegistry ditContentRuleRegistry )
     {
@@ -109,7 +109,7 @@ public class ImmutableDITContentRuleRegi
     /**
      * {@inheritDoc}
      */
-    public Iterator<DITContentRule> iterator()
+    public Iterator<DContentRule> iterator()
     {
         return immutableDITContentRuleRegistry.iterator();
     }
@@ -118,7 +118,7 @@ public class ImmutableDITContentRuleRegi
     /**
      * {@inheritDoc}
      */
-    public DITContentRule lookup( String oid ) throws LdapException
+    public DContentRule lookup( String oid ) throws LdapException
     {
         return immutableDITContentRuleRegistry.lookup( oid );
     }
@@ -136,7 +136,7 @@ public class ImmutableDITContentRuleRegi
     /**
      * {@inheritDoc}
      */
-    public void register( DITContentRule schemaObject ) throws LdapException
+    public void register( DContentRule schemaObject ) throws LdapException
     {
         throw new LdapUnwillingToPerformException( ResultCodeEnum.NO_SUCH_OPERATION, I18n.err( I18n.ERR_04277 ) );
     }
@@ -154,7 +154,7 @@ public class ImmutableDITContentRuleRegi
     /**
      * {@inheritDoc}
      */
-    public DITContentRule unregister( String numericOid ) throws LdapException
+    public DContentRule unregister( String numericOid ) throws LdapException
     {
         throw new LdapUnwillingToPerformException( ResultCodeEnum.NO_SUCH_OPERATION, I18n.err( I18n.ERR_04277 ) );
     }
@@ -172,7 +172,7 @@ public class ImmutableDITContentRuleRegi
     /**
      * {@inheritDoc}
      */
-    public DITContentRule get( String oid )
+    public DContentRule get( String oid )
     {
         return immutableDITContentRuleRegistry.get( oid );
     }
@@ -190,7 +190,7 @@ public class ImmutableDITContentRuleRegi
     /**
      * {@inheritDoc}
      */
-    public DITContentRule unregister( DITContentRule schemaObject ) throws LdapException
+    public DContentRule unregister( DContentRule schemaObject ) throws LdapException
     {
         throw new LdapUnwillingToPerformException( ResultCodeEnum.NO_SUCH_OPERATION, I18n.err( I18n.ERR_04277 ) );
     }
@@ -26,25 +26,25 @@ import org.apache.directory.shared.i18n.
 
 /**
- * An immutable wrapper of the DITContentRule registry.
+ * An immutable wrapper of the DContentRule registry.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
@@ -26,25 +26,25 @@ import org.apache.directory.shared.i18n.
 public class ImmutableDITContentRuleRegistry implements DITContentRuleRegistry
 {
-    /** The wrapped DITContentRule registry */
+    /** The wrapped DContentRule registry */
     DITContentRuleRegistry immutableDITContentRuleRegistry;
 
@@ -26,25 +26,25 @@ import org.apache.directory.shared.i18n.
      * Creates a new instance of ImmutableDITContentRuleRegistry.
      *
-     * @param ditContentRuleRegistry The wrapped DITContentRule registry
+     * @param ditContentRuleRegistry The wrapped DContentRule registry
      */
     public ImmutableDITContentRuleRegistry( DITContentRuleRegistry ditContentRuleRegistry )

Modified: directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/registries/Registries.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/registries/Registries.java?rev=1244570&r1=1244569&r2=1244570&view=diff
==============================================================================
--- directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/registries/Registries.java (original)
+++ directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/registries/Registries.java Wed Feb 15 16:29:04 2012
@@ -38,7 +38,7 @@ import org.apache.directory.shared.ldap.
 import org.apache.directory.shared.ldap.model.exception.LdapUnwillingToPerformException;
 import org.apache.directory.shared.ldap.model.message.ResultCodeEnum;
 import org.apache.directory.shared.ldap.model.schema.AttributeType;
-import org.apache.directory.shared.ldap.model.schema.DITContentRule;
+import org.apache.directory.shared.ldap.model.schema.DContentRule;
 import org.apache.directory.shared.ldap.model.schema.DITStructureRule;
 import org.apache.directory.shared.ldap.model.schema.LdapComparator;
 import org.apache.directory.shared.ldap.model.schema.LdapSyntax;
@@ -192,7 +192,7 @@ public class Registries implements Schem
 
 
     /**
      * @return The DITContentRule registry
      */
     public DITContentRuleRegistry getDitContentRuleRegistry()
     {
@@ -383,10 +383,10 @@ public class Registries implements Schem
             // Fall down to the next registry
         }
 
-        // DITContentRule
+        // DContentRule
         try
         {
-            DITContentRule ditContentRule = ditContentRuleRegistry.lookup( name );
+            DContentRule ditContentRule = ditContentRuleRegistry.lookup( name );
 
             if ( ditContentRule != null )
             {
@@ -609,7 +609,7 @@ public class Registries implements Schem
     private void buildDitContentRuleReferences( List<Throwable> errors )
     {
         for ( @SuppressWarnings("unused")
-        DITContentRule ditContentRule : ditContentRuleRegistry )
+        DContentRule ditContentRule : ditContentRuleRegistry )
         {
             // TODO
         }
@@ -670,7 +670,7 @@ public class Registries implements Schem
                     break;
                     
                 case DIT_CONTENT_RULE :
-                    DitContentRuleHelper.addToRegistries( (DITContentRule)schemaObject, errors, this );
+                    DitContentRuleHelper.addToRegistries( (DContentRule)schemaObject, errors, this );
                     break;
                     
                 case OBJECT_CLASS :
@@ -1535,7 +1535,7 @@ public class Registries implements Schem
                     break;
 
                 case DIT_CONTENT_RULE:
-                    ditContentRuleRegistry.register( ( DITContentRule ) schemaObject );
+                    ditContentRuleRegistry.register( ( DContentRule ) schemaObject );
                     break;
 
                 case DIT_STRUCTURE_RULE:
@@ -1753,7 +1753,7 @@ public class Registries implements Schem
                 break;
 
             case DIT_CONTENT_RULE:
-                unregistered = ditContentRuleRegistry.unregister( ( DITContentRule ) schemaObject );
+                unregistered = ditContentRuleRegistry.unregister( ( DContentRule ) schemaObject );
                 break;
 
             case DIT_STRUCTURE_RULE:
@@ -2509,7 +2509,7 @@ public class Registries implements Schem
             clone.globalOidRegistry.put( attributeType );
         }
 
-        for ( DITContentRule ditContentRule : clone.ditContentRuleRegistry )
+        for ( DContentRule ditContentRule : clone.ditContentRuleRegistry )
         {
             clone.globalOidRegistry.put( ditContentRule );
         }
@@ -192,7 +192,7 @@ public class Registries implements Schem
 
     /**
-     * @return The DITContentRule registry
+     * @return The DContentRule registry
      */
     public DITContentRuleRegistry getDitContentRuleRegistry()

Modified: directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/registries/helper/DitContentRuleHelper.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/registries/helper/DitContentRuleHelper.java?rev=1244570&r1=1244569&r2=1244570&view=diff
==============================================================================
--- directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/registries/helper/DitContentRuleHelper.java (original)
+++ directory/shared/trunk/ldap/model/src/main/java/org/apache/directory/shared/ldap/model/schema/registries/helper/DitContentRuleHelper.java Wed Feb 15 16:29:04 2012
@@ -22,7 +22,7 @@ package org.apache.directory.shared.ldap
 import java.util.List;
 
 import org.apache.directory.shared.ldap.model.exception.LdapException;
-import org.apache.directory.shared.ldap.model.schema.DITContentRule;
+import org.apache.directory.shared.ldap.model.schema.DContentRule;
 import org.apache.directory.shared.ldap.model.schema.registries.AttributeTypeRegistry;
 import org.apache.directory.shared.ldap.model.schema.registries.ObjectClassRegistry;
 import org.apache.directory.shared.ldap.model.schema.registries.Registries;
@@ -41,13 +41,13 @@ public class DitContentRuleHelper
     private static final Logger LOG = LoggerFactory.getLogger( DitContentRuleHelper.class );
 
     /**
      * Inject the DITContentRule into the registries, updating the references to
      * other SchemaObject
      *
      * @param registries The Registries
      * @exception If the addition failed
      */
-    public static void addToRegistries( DITContentRule ditContentRule, List<Throwable> errors,  Registries registries ) throws LdapException
+    public static void addToRegistries( DContentRule ditContentRule, List<Throwable> errors,  Registries registries ) throws LdapException
     {
         if ( registries != null )
         {
@@ -41,13 +41,13 @@ public class DitContentRuleHelper
 
     /**
-     * Inject the DITContentRule into the registries, updating the references to
+     * Inject the DContentRule into the registries, updating the references to
      * other SchemaObject
      *

Modified: directory/shared/trunk/ldap/model/src/test/java/org/apache/directory/shared/ldap/model/schema/syntaxes/parser/DITContentRuleDescriptionSchemaParserTest.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/model/src/test/java/org/apache/directory/shared/ldap/model/schema/syntaxes/parser/DITContentRuleDescriptionSchemaParserTest.java?rev=1244570&r1=1244569&r2=1244570&view=diff
==============================================================================